==> chromium_88.0.4324.96.orig.tar.xz: chromium-88.0.4324.96/chrome/browser/chromeos/scanning/lorgnette_scanner_manager_factory.cc <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/chromeos/scanning/lorgnette_scanner_manager_factory.h"

#include "base/memory/singleton.h"
#include "chrome/browser/chromeos/profiles/profile_helper.h"
#include "chrome/browser/chromeos/scanning/lorgnette_scanner_manager.h"
#include "chrome/browser/chromeos/scanning/zeroconf_scanner_detector.h"
#include "chrome/browser/profiles/profile.h"
#include "components/keyed_service/content/browser_context_dependency_manager.h"
#include "content/public/browser/browser_context.h"

namespace chromeos {

// static
LorgnetteScannerManager* LorgnetteScannerManagerFactory::GetForBrowserContext(
    content::BrowserContext* context) {
  return static_cast<LorgnetteScannerManager*>(
      LorgnetteScannerManagerFactory::GetInstance()
          ->GetServiceForBrowserContext(context, /*create=*/true));
}

// static
LorgnetteScannerManagerFactory* LorgnetteScannerManagerFactory::GetInstance() {
  return base::Singleton<LorgnetteScannerManagerFactory>::get();
}

LorgnetteScannerManagerFactory::LorgnetteScannerManagerFactory()
    : BrowserContextKeyedServiceFactory(
          "LorgnetteScannerManager",
          BrowserContextDependencyManager::GetInstance()) {}

LorgnetteScannerManagerFactory::~LorgnetteScannerManagerFactory() = default;

KeyedService* LorgnetteScannerManagerFactory::BuildServiceInstanceFor(
    content::BrowserContext* context) const {
  // Prevent an instance of LorgnetteScannerManager from being created on the
  // lock screen.
  Profile* profile = Profile::FromBrowserContext(context);
  if (ProfileHelper::IsLockScreenAppProfile(profile) ||
      ProfileHelper::IsSigninProfile(profile)) {
    return nullptr;
  }

  return LorgnetteScannerManager::Create(ZeroconfScannerDetector::Create())
      .release();
}

bool LorgnetteScannerManagerFactory::ServiceIsCreatedWithBrowserContext()
    const {
  return true;
}

bool LorgnetteScannerManagerFactory::ServiceIsNULLWhileTesting() const {
  return true;
}

}  // namespace chromeos

==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/chromeos/scanning/lorgnette_scanner_manager_factory.cc <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/chromeos/scanning/lorgnette_scanner_manager_factory.h"

#include "base/memory/singleton.h"
#include "chrome/browser/chromeos/profiles/profile_helper.h"
#include "chrome/browser/chromeos/scanning/lorgnette_scanner_manager.h"
#include "chrome/browser/chromeos/scanning/zeroconf_scanner_detector.h"
#include "chrome/browser/profiles/profile.h"
#include "components/keyed_service/content/browser_context_dependency_manager.h"
#include "content/public/browser/browser_context.h"

namespace chromeos {

// static
LorgnetteScannerManager* LorgnetteScannerManagerFactory::GetForBrowserContext(
    content::BrowserContext* context) {
  return static_cast<LorgnetteScannerManager*>(
      LorgnetteScannerManagerFactory::GetInstance()
          ->GetServiceForBrowserContext(context, /*create=*/true));
}

// static
LorgnetteScannerManagerFactory* LorgnetteScannerManagerFactory::GetInstance() {
  return base::Singleton<LorgnetteScannerManagerFactory>::get();
}

LorgnetteScannerManagerFactory::LorgnetteScannerManagerFactory()
    : BrowserContextKeyedServiceFactory(
          "LorgnetteScannerManager",
          BrowserContextDependencyManager::GetInstance()) {}

LorgnetteScannerManagerFactory::~LorgnetteScannerManagerFactory() = default;

KeyedService* LorgnetteScannerManagerFactory::BuildServiceInstanceFor(
    content::BrowserContext* context) const {
  // Prevent an instance of LorgnetteScannerManager from being created on the
  // lock screen.
  Profile* profile = Profile::FromBrowserContext(context);
  if (!ProfileHelper::IsRegularProfile(profile)) {
    return nullptr;
  }

  return LorgnetteScannerManager::Create(ZeroconfScannerDetector::Create())
      .release();
}

bool LorgnetteScannerManagerFactory::ServiceIsCreatedWithBrowserContext()
    const {
  return true;
}

bool LorgnetteScannerManagerFactory::ServiceIsNULLWhileTesting() const {
  return true;
}

}  // namespace chromeos
